ATel #12503: FDST spectroscopic classification of SN 2019awc

Outside GCN IAUCs Other ATel on Twitter and Facebook ATELstream ATel Community Site | Post | Search | Policies Credential | Feeds | Email 4 May 2020; 09:26 UT | This space for free for your conference.

[ Previous | Next | ADS ] # FDST spectroscopic classification of SN 2019awc ATel #12503; C. P. Gutierrez (University of Southampton), C. Frohmaier (University of Portsmouth - ICG), T. Muller-Bravo (University of Southampton), C. Inserra (Cardiff University), J. Anderson (ESO), C. Angus (University of Southampton), R. Cartier (CTIO), T.-W. Chen (MPE), T. de Jaeger (UC Berkeley), L. Galbany (University of Pittsburg), S. Gonzalez-Gaitan (CENTRA), M. Grayling (University of Southampton), H. Kuncarayakti (University of Turku), J. Lyman (University of Warwick), A. Pastorello (INAF - Padova Astronomical Observatory) M. Pursiainen (University of Southampton), R. Roy (IUCAA), T. Schweyer (MPE), M. Smith (University of Southampton), M. Sullivan (University of Southampton), P. Wiseman (University of Southampton). on 14 Feb 2019; 18:40 UT Credential Certification: Claudia Gutierrez (c.p.gutierrez-avendano@soton.ac.uk) Subjects: Optical, Supernovae, Transient Tweet The Fast and Dark Side of Transients experiment (FDST; ATel #12362) reports the spectroscopic observation of SN 2019awc. Targets were supplied by the Zwicky Transient Facility (https://www.ztf.caltech.edu/; Kulkarni et al. 2018, ATel 11266) and processed through the Lasair broker (http://lasair.roe.ac.uk/). Classifications were done with SNID (Blondin & Tonry, 2007, ApJ, 666, 1024). The observations were performed on 2019-02-13 using SPRAT (Piascik et al 2014) on the Liverpool Telescope (Steele et al. 2004).
    Survey Name  | IAU Name  | RA (J2000)   | Dec (J2000)  | Disc. Date  | Source | Disc Mag |  z    | Type    | Phase      | Notes
    ZTF19aailuvj | SN2019awc |  15:27:30.21 | +28:41:58.14 |  20190208   |  ZTF   |   19.96  | 0.071 |  Ia     | before max | (1)
(1) Redshift obtained from SNID best fit. The phase obtained with SNID is between -9 and -5 days. |